% fig_06_10
% plot the 2D traction ellipsoid given principal tractions
% plot traction director surface with tangent and normal lines
% equations (6.21) and (6.23)

clear all, clf reset; %clear memory and figures

% Plot 2D Section of Traction Ellipsoid
t1 = .8; % magnitude of greatest traction
t2 = .5; % magnitude of intermediate traction
TXN = linspace(0,t1,300); % vector of tx(n) coordinates
TYN = sqrt((1-(TXN./t1).^2)*(t2^2)); % vector of ty(n) coordinates
plot(TXN,TYN,'k'), hold on
axis equal, axis([0,1,0,1])
%axis([0,1.2*t1,0,1.2*t1])
xlabel('tx(n)'), ylabel('ty(n)')

% Plot particular traction vector
txn = 0.5*t1; % x-component of particular traction
tyn = sqrt((1-(txn/t1)^2)*(t2^2)); % y-component of particular traction
plot([0,txn],[0,tyn],'k'), hold off

% Plot 2D Section of Traction Director Surface
X = linspace(0,sqrt(t1),50); % vector of x coordinates
Y = sqrt((1-(X.^2)/t1)*t2); % vector of y coordinates
% plot section of traction director surface
figure, plot(X,Y,'k'), hold on
axis equal, axis([0,1,0,1])
%axis([0,1.2*sqrt(t1),0,1.2*sqrt(t1)])
xlabel('x'), ylabel('y')
% Plot line parallel to particular traction on TDS
plot([0,t1],[0,(tyn/txn)*t1],'k')

% Plot Tangent Plane to TDS at (xo, yo)
xo = sqrt(t2/((t2/t1)+(tyn/txn)^2)); 
yo = sqrt((1-(xo^2)/t1)*t2);
XT = linspace(0.5*xo,1.5*xo,10);
YT = (1-(XT*xo/t1))*(t2/yo);
plot(XT,YT,'k')

%Plot Normal to TDS at (xo, yo)
h = txn/xo;
x1 = xo + (0.5*h)*(txn/t1);
y1 = yo + (0.5*h)*(tyn/t2);
plot([xo,x1],[yo,y1],'k')

