% fig_06_20
% plot the 3D traction ellipsoid given a state of stress
% equations (6.21) and (6.40)

clear all, clf reset; %clear memory and figures
% Define the 6 stress tensor components in Cartesian coordinates
sxx = 1; syy = .5; szz = .25; sxy = .25; syz = .25;  szx = .25;

% Define the components of m x n unit radius vectors, N, with heads at 
% intersections of lines of longitude and latitude on unit sphere.
m = 37; n = 19;
lm = linspace(0,2*pi,m); % lambda coordinates on parameter plane
ph = linspace(0+eps,pi-eps,n); % phi coordinatess on parameter plane
[LM,PH]=meshgrid(lm,ph);  % grid of points on parameter plane
NX = cos(LM).*sin(PH); % x-component of radius vector
NY = sin(LM).*sin(PH); % y-component of radius vector
NZ = cos(PH); % z-component of radius vector
mesh(NX,NY,NZ) % 3D mesh surface plot of unit sphere
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')
title('The Unit Sphere'), axis equal

% Calculate components of traction vectors, T, on surfaces 
%  with normals N using Cauchy's Formula
TX = sxx.*NX + sxy.*NY + szx.*NZ;
TY = sxy.*NX + syy.*NY + syz.*NZ;
TZ = szx.*NX + syz.*NY + szz.*NZ;
OR = 0*TX; % zero matrix of same size as TX
figure, quiver3(OR,OR,OR,TX,TY,TZ) % 3D quiver plot of traction vectors
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')
title('The Traction Vectors'), axis equal 

% 3D mesh surface plot of traction ellipsoid with color scaled to
% magnitude of traction vectors
T = sqrt(TX.^2 + TY.^2 + TZ.^2); % magnitudes of traction vectors, T
figure, mesh(TX,TY,TZ,T) 
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')
title('The Traction Ellipsoid'), axis equal