% fig_06_25
% Cartesian stress components in a circular disk under diametrically
% opposed point forces
% Frock (1948,p. 126)
% equations (6.97) - (6.99)

clear all, clf reset; clear memory and figures
r = 1; d = 2*r; t = 1; % radius and thickness of disk
p = 1; % force magnitude
c = (2*p)/(pi*t);
x = linspace(-r,r,100)+eps; % add eps to avoid singularity at origin
y = linspace(-r,r,100);
[X,Y] = meshgrid(x,y); % define Cartesian grid
X2 = X.^2; 
MY = r-Y; MY2 = MY.^2; MY3 = MY.^3;
PY = r+Y; PY2 = PY.^2; PY3 = PY.^3;
R1 = sqrt(X2+MY2); R2 = sqrt(X2+PY2);
% compute Cartesian stress components
SXX = -c*(((MY.*X2)./R1.^4)+((PY.*X2)./R2.^4)-(1/d));
SYY = -c*((MY3./R1.^4)+(PY3./R2.^4)-(1/d));
SXY = c*(((MY2.*X)./R1.^4)-((PY2.*X)./R2.^4));
% convert Cartesian to polar coordinates
[TH,R] = cart2pol(X,Y); 
% avoid grid points outside disk
SXX(find(R>r)) = nan; SYY(find(R>r)) = nan; SXY(find(R>r)) = nan;
% avoid grid points near point of load application at top of disk
SXX(find(R1<r/10)) = nan; SYY(find(R1<r/10)) = nan; SXY(find(R1<r/10)) = nan; 
% avoid grid points near point of load application at bottom of disk
SXX(find(R2<r/10)) = nan; SYY(find(R2<r/10)) = nan; SXY(find(R2<r/10)) = nan; 

% plot filled contour maps of Cartesian stress components
subplot(2,2,1), contourf(X,Y,SXX,10), colorbar
title('stress sxx'), axis equal
subplot(2,2,3), contourf(X,Y,SYY,10), colorbar
title('stress syy'), axis equal
subplot(2,2,4), contourf(X,Y,SXY,10), colorbar
title('stress sxy'), axis equal

% calculate principal stresses, max. shear stress, and mean normal stress
S1 = 0.5*(SXX+SYY)+sqrt(((0.25*(SXX-SYY).^2)+SXY.^2));
S2 = 0.5*(SXX+SYY)-sqrt(((0.25*(SXX-SYY).^2)+SXY.^2));
SS = 0.5*(S1-S2); SM = 0.5*(S1+S2);

% plot filled contour maps of principal stresses
figure, subplot(2,2,1), contourf(X,Y,S1,10), colorbar
title('stress s1'), axis equal
subplot(2,2,2), contourf(X,Y,S2,10), colorbar
title('stress s2'), axis equal
subplot(2,2,3), contourf(X,Y,SS,10), colorbar
title('stress ss'), axis equal
subplot(2,2,4), contourf(X,Y,SM,10), colorbar
title('stress sm'), axis equal

figure, % colormap(gray) 
contourf(X,Y,SS,25), colorbar, title('stress ss'), axis equal
