% fig_06_34b
% Circular hole in infinite plate, biaxial remote stress, internal pressure
% Plot stress components on hole perimeter.
% Jaeger and Cook (1979)equations (6.108) - (6.111)
clear all, clf reset; % clear memory and figures
ri = 1; % hole radius
sH = 3; sh = 2; % remote principal compressive stress magnitudes
pm = 4; % pressure in the hole
% plot polar stress components on hole perimeter
TH = 0:pi/18:pi/2; THD = TH*180/pi; % Angle theta
R = ones(size(TH)); % radial coordinate at edge of hole
ST = sin(TH); S2T = sin(2*TH); ST2 = ST.^2; 
CT = cos(TH); C2T = cos(2*TH); CT2 = CT.^2;
R2 = (ri./R).^2; R4 = R2.^2;
% Polar stress components
SRR = -(0.5*(sH+sh)*(1-R2))-(pm*R2)-(0.5*(sH-sh)*((1-4*R2+3*R4).*C2T));
STT = -(0.5*(sH+sh)*(1+R2))+(pm*R2)+(0.5*(sH-sh)*((1+3*R4).*C2T));
SRT = 0.5*(sH-sh)*((1+2*R2-3*R4).*S2T);
plot(THD,SRR,'k-',THD,STT,'k-.',THD,SRT,'k--');
xlabel('theta (degrees)'); ylabel('stress');
legend('SRR','STT','SRT');
axis ([0 90 -5 3]);