% fig_06_34a
% Circular hole in infinite plate, biaxial remote stress, internal pressure
% Plot stress components on radial lines.
% Jaeger and Cook (1979) equations (6.108) - (6.111)
clear all, clf reset; % clear memory and figures
% plot polar stress components on radial line
thd = 0; th = thd*pi/180; % orientation of radial line
ri = 1; % radius of hole 
sH = 2; sh = 0.5; % magnitudes of remote principal stresses
pm = 1; % magnitude of pressure in hole
R = ri:ri/10:ri*10; % radial coordinate on radial line from perimeter
TH = th*ones(size(R)); THD = TH*180/pi; % Angle theta
ST = sin(TH); S2T = sin(2*TH); ST2 = ST.^2; 
CT = cos(TH); C2T = cos(2*TH); CT2 = CT.^2;
R2 = (ri./R).^2; R4 = R2.^2;
% Polar stress components from equations 6.108 - 6.110
SRR = -(0.5*(sH+sh)*(1-R2))-(pm*R2)-(0.5*(sH-sh)*((1-4*R2+3*R4).*C2T));
STT = -(0.5*(sH+sh)*(1+R2))+(pm*R2)+(0.5*(sH-sh)*((1+3*R4).*C2T));
SRT = 0.5*(sH-sh)*((1+2*R2-3*R4).*S2T);
plot(R,SRR,'k-',R,STT,'k-.',R,SRT,'k--');
xlabel('R/ri'); ylabel('stress');
legend('SRR','STT','SRT');
axis ([0 10 -2 2])